# Generated by Django 3.2.25 on 2024-06-24 12:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('game', '0093_alter_level_character_name'),
    ]

    operations = [
        migrations.AddField(
            model_name='level',
            name='hint',
            field=models.TextField(default='Think back to earlier levels. What did you learn?', max_length=10000),
        ),
        migrations.AddField(
            model_name='level',
            name='lesson',
            field=models.TextField(default='Can you find the shortest route?', max_length=10000),
        ),
        migrations.AddField(
            model_name='level',
            name='subtitle',
            field=models.TextField(blank=True, max_length=100, null=True),
        ),
    ]
