# we should comment out languages that we don't have custom block translations for,
# although all these languages have built-in translations for the generic blocks

language_code_dict = {
  # "ab": "аҧсуа бызшәа",
  # "ar": "العربية",
  # "az": "azərbaycan",
  # "ba": "Башҡорт теле",
  # "bcc": "بلۏچی",
  # "be": "беларуская",
  # "be-tarask": "тарашкевіца",
  # "bg": "български",
  # "bn": "বাংলা",
  # "br": "Brezhoneg",
  "ca": "Català",
  # "cs": "čeština",
  # "da": "Dansk",
  # "de": "Deutsch",
  # "diq": "Zazakî",
  # "dty": "डोटेली",
  # "el": "Ελληνικά",
  "en": "English",
  "en-gb": "English (UK)",
  # "eo": "Esperanto",
  "es": "Español",
  # "et": "Eesti",
  # "eu": "Euskara",
  # "fa": "فارسی",
  # "fi": "Suomi",
  "fr": "Français",
  # "gl": "Galego",
  # "gor": "Hulontalo",
  # "ha": "Hausa",
  # "he": "עברית",
   "hi": "हिन्दी",
  # "hrx": "Hunsrik",
  # "hu": "Magyar",
  # "hy": "հայերեն",
  # "ia": "Interlingua",
  # "id": "Bahasa Indonesia",
  # "ig": "Igbo",
  # "is": "íslenska",
  # "it": "Italiano",
  # "ja": "日本語",
  # "kab": "Taqbaylit",
  # "ko": "한국어",
  # "lb": "Lëtzebuergesch",
  # "lki": "له‌کی",
  # "lo": "ລາວ",
  # "lrc": "لۊری شومالی",
  # "lt": "Lietuvių",
  # "lv": "Latviešu",
  # "mk": "македонски",
  # "mnw": "ဘာသာမန်",
  # "ms": "Bahasa Malaysia",
  # "nb": "Norsk bokmål",
  # "nl": "Nederlands",
  # "oc": "Occitan",
  # "pl": "Polski",
  # "pms": "Piemontèis",
  # "pt": "Português",
  # "pt-br": "Português (Brasil)",
  # "ro": "Română",
  # "ru": "русский",
  # "sc": "Sardu",
  # "sd": "سنڌي",
  # "shn": "လိၵ်ႈတႆး",
  # "sk": "Slovenčina",
  # "skr-arab": "سرائیکی",
  # "sl": "Slovenščina",
  # "sq": "Shqip",
  # "sr": "српски",
  # "sr-latn": "Srpski",
  # "sv": "Svenska",
  # "ta": "தமிழ்",
  # "tcy": "ತುಳು",
  # "te": "తెలుగు",
  # "th": "ไทย",
  # "tl": "Tagalog",
  # "tlh": "tlhIngan Hol",
  # "tr": "Türkçe",
  # "ug-arab": " ئۇيغۇرچە",
  # "uk": "українська",
  # "ur": "اردو",
  # "vi": "Tiếng Việt",
  # "xmf": "მარგალური ნინა",
  # "yo": "Èdè Yorùbá",
  # "zh-hans": "简体中文",
  # "zh-hant": "繁體中文"
}