# Generated by Django 3.2.23 on 2023-12-19 21:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('game', '0086_loop_levels'),
    ]

    operations = [
        migrations.AddField(
            model_name='workspace',
            name='python_view_enabled',
            field=models.BooleanField(default=False),
        ),
    ]
