/*  CSS file for components shared between game and level_editor **/

.top-bar {
  display: none;
}

#wrapper {
  position: fixed;
  overflow: auto;
  left: 0;
  right: 0;
  top: 0;
  bottom: 0;
}

.col {
  float: left;
}

.unselectable {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

/**********/
/* Popups */
/**********/

.ocargo-modal-mainText {
  font-size: 1.2rem !important;
}
.ocargo-modal-lead {
  font-size: 1.4rem !important;
}

.ocargo-modal-mainText > #hintText {
  display: none;
  margin: 2rem 1rem 0;
}

.ocargo-modal-mainText > #hintBtnPara {
  margin: 2rem 1rem 0;
}

.ocargo-modal img {
  margin-right: 0.2rem;
}

.modal_image {
  width: 100px;
  height: 100px;
  padding: 10px;
  margin-right: 30px;
  border: solid 5px;
  border-color: rgb(246, 146, 30);
  border-radius: 12px;

  background: #fbed21; /* Old browsers */
  background: -moz-linear-gradient(top, #fbed21 0%, #faaf3b 100%); /* FF3.6+ */
  background: -webkit-gradient(
    linear,
    left top,
    left bottom,
    color-stop(0%, #fbed21),
    color-stop(100%, #faaf3b)
  ); /* Chrome,Safari4+ */
  background: -webkit-linear-gradient(
    top,
    #fbed21 0%,
    #faaf3b 100%
  ); /* Chrome10+,Safari5.1+ */
  background: -o-linear-gradient(
    top,
    #fbed21 0%,
    #faaf3b 100%
  ); /* Opera 11.10+ */
  background: -ms-linear-gradient(top, #fbed21 0%, #faaf3b 100%); /* IE10+ */
  background: linear-gradient(to bottom, #fbed21 0%, #faaf3b 100%); /* W3C */
}

.ocargo-modal .navigation_button {
  margin-top: 20px;
  margin-right: 20px;
}

/************/
/** Tables **/
/************/

.scrolling-table-wrapper {
  position: relative;
  border: solid 1px #dddddd;
}

.scrolling-table {
  max-height: 180px;
  overflow: auto;
}

.scrolling-table td {
  cursor: pointer;
}

.scrolling-table tr[selected] {
  background: #fbed21; /* Old browsers */
  background: -moz-linear-gradient(top, #fbed21 0%, #faaf3b 100%); /* FF3.6+ */
  background: -webkit-gradient(
    linear,
    left top,
    left bottom,
    color-stop(0%, #fbed21),
    color-stop(100%, #faaf3b)
  ); /* Chrome,Safari4+ */
  background: -webkit-linear-gradient(
    top,
    #fbed21 0%,
    #faaf3b 100%
  ); /* Chrome10+,Safari5.1+ */
  background: -o-linear-gradient(
    top,
    #fbed21 0%,
    #faaf3b 100%
  ); /* Opera 11.10+ */
  background: -ms-linear-gradient(top, #fbed21 0%, #faaf3b 100%); /* IE10+ */
  background: linear-gradient(to bottom, #fbed21 0%, #faaf3b 100%); /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#fbed21', endColorstr='#faaf3b',GradientType=0 ); /* IE6-9 */
}

table {
  border-collapse: collapse;
  border-spacing: 0px;
  border: none;
}

table th {
  border-bottom: solid 1px #dddddd;
}

/*************/
/** Buttons **/
/*************/


.navigation_button_portal {
  min-width: 180px;
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  align-content: space-around;
  align-items: stretch;
  position: relative;
  overflow: hidden;
  text-align: center;
  background: #ffd23b;
  border-radius: 8px;
  cursor: pointer;
  color: black;
  padding: 0px;
}

.navigation_button_portal_secondary {
  min-width: 180px;
  position: relative;
  overflow: hidden;
  text-align: center;
  background: transparent;
  border-radius: 8px;
  cursor: pointer;
  color: black;
  padding: 0px;
  border: 3px solid #eab502;
  display: flex;
  flex-direction: row;
  align-items: center;
}

.navigation_button_portal:hover,
.navigation_button_portal:active,
.navigation_button_portal:focus {
  box-shadow: 0px 6px 10px 0px rgb(0 0 0 / 14%), 0px 1px 18px 0px rgb(0 0 0 / 12%), 0px 3px 5px 0px rgb(0 0 0 / 20%);
  background: #ffd23b;
}

.navigation_button_portal_secondary:hover,
.navigation_button_portal_secondary:active,
.navigation_button_portal_secondary:focus {
  text-decoration: underline;
  color: black;
  background: white;
}

.navigation_button_portal_secondary:hover > svg,
.navigation_button_portal_secondary:focus > svg {
  color: black;
}

.rapid-router-welcome {
  width: 13rem;
}

.modal-buttons > button > svg {
  height: 100%;
  width: 20%;
}

#prev_button > span,
#next_button > span {
  padding: 0;
  margin: 0;
}

#prev_button,
#next_button {
  justify-content: space-between;
}

#prev_button {
  flex-direction: row-reverse;
  padding-right: 1rem;
}

#next_button {
  padding-left: 1rem;
}

button > svg {
  width: 30%;
  height: 30%;
}

#run-code {
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
  background: #3b3b3b;
  padding: 0rem 1rem 0rem 0rem;
  margin-bottom: 0.25rem;
}

.navigation_button_kurono {
  height: 50px !important;
  font-size: 20px;
  min-width: 180px;
  display: flex;
  flex-direction: row;
  flex-wrap: wrap;
  align-items: center;
  justify-content: space-around;
  position: relative;
  overflow: hidden;
  text-align: center;
  background: #f5f5f5;
  border-radius: 8px;
  cursor: pointer;
  color: black;
  padding: 0.5rem 1rem 0.5rem 1rem ;
}

.navigation_button_kurono > img,
.navigation_button_kurono > svg {
  height: 24px;
  width: 24px;
}

.navigation_button_kurono:hover,
.navigation_button_kurono:focus {
  color: black;
  background: #f5f5f5;
  box-shadow: 0px 6px 10px 0px rgb(0 0 0 / 14%), 0px 1px 18px 0px rgb(0 0 0 / 12%), 0px 3px 5px 0px rgb(0 0 0 / 20%);
}

.description {
  height: 100%;
}

.navigation_button {
  display: inline-block;
  position: relative;
  overflow: hidden;
  text-align: center;
  background: rgb(255, 210, 59);
  border: none;
  cursor: pointer;
  color: black;
  padding: 0px;
}

.navigation_button:hover,
.navigation_button:focus {
  box-shadow: 0px 6px 10px 0px rgb(0 0 0 / 14%), 0px 1px 18px 0px rgb(0 0 0 / 12%), 0px 3px 5px 0px rgb(0 0 0 / 20%);
  background: rgb(255, 210, 59);
}

.navigation_button:active {
  background: #f9d922; /* Old browsers */
  background: -moz-linear-gradient(top, #f9d922 0%, #f7933b 100%); /* FF3.6+ */
  background: -webkit-gradient(
    linear,
    left top,
    left bottom,
    color-stop(0%, #f9d922),
    color-stop(100%, #f7933b)
  ); /* Chrome,Safari4+ */
  background: -webkit-linear-gradient(
    top,
    #f9d922 0%,
    #f7933b 100%
  ); /* Chrome10+,Safari5.1+ */
  background: -o-linear-gradient(
    top,
    #f9d922 0%,
    #f7933b 100%
  ); /* Opera 11.10+ */
  background: -ms-linear-gradient(top, #f9d922 0%, #f7933b 100%); /* IE10+ */
  background: linear-gradient(to bottom, #f9d922 0%, #f7933b 100%); /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f9d922', endColorstr='#f7933b',GradientType=0 ); /* IE6-9 */
  outline: none;
  color: black;
}

.navigation_button:disabled {
  border-color: rgb(246, 146, 30);
}

.long_button {
  min-width: 120px;
  font-size: 20px;
  height: 42px;
  margin-top: 5px;
  margin-bottom: 5px;
}

.long_button img {
  height: 30px;
  margin-right: 8px;
  margin-left: 8px;
  float: left;
}

.long_button span {
  line-height: 30px;
  margin-left: auto;
  margin-right: auto;
  padding-left: 10px;
  padding-right: 10px;
}

.navigation_button_portal_secondary.long_button span {
  text-align: left;
  margin: 0;
  width: 100%;
}

.long_button img + span {
  line-height: 30px;
  margin-left: 2px;
  margin-right: 15px;
  float: left;
}

.long_button img,
.long_button span {
  vertical-align: middle;
  color: black;
}

/*****************/
/* Tab structure */
/*****************/

.tab {
  list-style: none;
  width: 100%;
  height: 40px;
  padding-top: 10px;

}

.tab.hidden {
  display: none;
}

.tab input[type='radio'] {
  display: none;
  margin: 0;
}

.tab input[type='radio'] + label {
  text-align: left;
  margin: 0;
  display: block;
  padding: 5px 5px 5px 5px;
  font-weight: bold;
  width: 100%;
  -webkit-transition: all 0.2s ease-in-out;
  -moz-transition: all 0.2s ease-in-out;
  -o-transition: all 0.2s ease-in-out;
  transition: all 0.2s ease-in-out;
}

div.no-print div.tab label {
  display: flex;
  flex-direction: row;
}

.tab label svg {
  width: 20px;
  height: 20px;
  margin-right: 5px;
  margin-left: 2px;
}


.tab label img {
  width: 20px;
  height: 20px;
  margin-right: 5px;
}

.tab label span {
  line-height: 20px;
}

.tab label:hover,
.tab input[type='radio']:checked + label {
  background: rgba(255, 255, 255, 0.25);
}

.tab select:hover {
  background: rgba(255, 255, 255, 0.25);
}

.tab select {
  color: black;
  border: none;
  font-weight: bold;
  padding-right: 20px;
}

#console {
  z-index: 100;
  display: flex;
  flex-direction: column;
  margin: 0;
}

#console > .console-text {
  background:rgb(81, 81, 81);
  display:flex;
  flex-direction: row;
  padding: 0.5rem 0rem 0.5rem 3rem;
}

#console > div > p {
  margin: 0;
}

#console > div > p > strong {
  color: white;
}

.clear-console {
  display: flex;
  flex-direction: row;
  justify-content: flex-end;
  background: white;
  margin: 0.5rem 0.5rem 0.5rem 0.5rem;
}

.intro-level {
  padding:10px 10px 10px 10px;
}

.tab_pane {
  position: relative;
  z-index: 2;
  text-align: left;
  width: 100%;
  height: 100%;
  font-size: 20px;
  line-height: 140%;
  background-color: white;
  box-sizing: border-box;
  -webkit-animation-duration: 0.5s;
  -o-animation-duration: 0.5s;
  -moz-animation-duration: 0.5s;
  animation-duration: 0.5s;
  overflow: hidden;
}

#tab_panes_wrapper .tab_pane {
  padding: 20px 20px 0 30px;
  overflow: scroll;
  position: absolute;
  width: 380px;
}

#scenery_pane {
  overflow: visible !important;
}

.tab_break {
  width: auto;
  height: 20px;
}

.tab_pane h2 {
  margin-bottom: 15px;
}

/**********/
/* Modals */
/**********/

#myModal {
  overflow: hidden;
}

#modal-content {
  float: left;
  width: 100%;
}

.modal-buttons {
  margin-top: 4rem;
  display:flex;
  flex-direction: row;
  justify-content: space-between;
  width: 100%;
}

#modal-buttons button {
  margin-right: 0.5em;
}

#modal-mascot,
#modal-mascot--brain {
  float: right;
  width: 20%;
}

#modal-mascot--brain {
  transform: scaleX(-1);
}

#myModal pre {
  margin: 1em 2em 0.3em;
}
