# Generated by Django 3.2.25 on 2024-06-11 14:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('game', '0092_disable_algo_score_in_custom_levels'),
    ]

    operations = [
        migrations.AlterField(
            model_name='level',
            name='character_name',
            field=models.CharField(blank=True, choices=[('Van', 'Van'), ('Dee', 'Dee'), ('Nigel', 'Nigel'), ('Kirsty', 'Kirsty'), ('Wes', 'Wes'), ('Phil', 'Phil'), ('Electric van', 'Electric van')], default=None, max_length=20, null=True),
        ),
    ]
